@@ -333,12 +333,13 @@ def get_customer_consumption(uuid):
     """
     try:
         product_out_fup = request.args.get('product_out_fup', None)
-        if product_out_fup.lower() == 'true':
-            kwargs = {
-                'table_customer': 'customer_ese',
-                'table_cdr': 'cdr_ese'
-            }
-            customer = lib_customer.Customer(uuid, **kwargs)
+        if product_out_fup:
+            if product_out_fup.lower() == 'true':
+                kwargs = {
+                    'table_customer': 'customer_ese',
+                    'table_cdr': 'cdr_ese'
+                }
+                customer = lib_customer.Customer(uuid, **kwargs)
         else:
             product_out_fup = False
             customer = lib_customer.Customer(uuid)
