@@ -849,7 +849,11 @@ class Customer(object):
             elif info['total'] < info['data_limit'] and status:
                 info['fup_out'] = True
             if for_real:
+                # FUP the customer in Aiguiller
                 if info.get('fup_in'):  # à limiter
+                    LOGS.logger.info(
+                        "> FUP-ing Customer '{}'...".format(self.name)
+                    )
                     if info['period'] == 'try':
                         params['actif'] = 'FALSE'
                     else:
@@ -897,7 +901,11 @@ class Customer(object):
                         params=params
                         )
                     """
+                # DEFUP the customer in Aiguiller
                 elif info.get('fup_out'):  # libérer
+                    LOGS.logger.info(
+                        "> DEFUP-ing Customer '{}'...".format(self.name)
+                    )
                     if info['period'] == 'try':
                         params['actif'] = 'TRUE'
                         method = 'post'
